==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_functions/mp0612_001/MP0612_AddPartsAssociated_001.java <==

package net.datastream.schemas.mp_functions.mp0612_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.partsassociated_001.PartsAssociated;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PartsAssociated_001}PartsAssociated"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PartsAssociated" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_delete_partlocation" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partsAssociated"
})
@XmlRootElement(name = "MP0612_AddPartsAssociated_001")
public class MP0612_AddPartsAssociated_001 {

    @XmlElement(name = "PartsAssociated", namespace = "http://schemas.datastream.net/MP_entities/PartsAssociated_001", required = true)
    protected PartsAssociated partsAssociated;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_delete_partlocation")
    protected String confirm_Delete_Partlocation;

    /**
     * Obtient la valeur de la propriété partsAssociated.
     * 
     * @return
     *     possible object is
     *     {@link PartsAssociated }
     *     
     */
    public PartsAssociated getPartsAssociated() {
        return partsAssociated;
    }

    /**
     * Définit la valeur de la propriété partsAssociated.
     * 
     * @param value
     *     allowed object is
     *     {@link PartsAssociated }
     *     
     */
    public void setPartsAssociated(PartsAssociated value) {
        this.partsAssociated = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PARTS_ASSOCIATED;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Delete_Partlocation.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Delete_Partlocation() {
        if (confirm_Delete_Partlocation == null) {
            return "prompt";
        } else {
            return confirm_Delete_Partlocation;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Delete_Partlocation.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Delete_Partlocation(String value) {
        this.confirm_Delete_Partlocation = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp0612_001/MP0612_AddPartsAssociated_001.java <==

package net.datastream.schemas.mp_functions.mp0612_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.partsassociated_001.PartsAssociated;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/PartsAssociated_001}PartsAssociated"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PartsAssociated" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="confirm_delete_partlocation" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="prompt" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partsAssociated"
})
@XmlRootElement(name = "MP0612_AddPartsAssociated_001")
public class MP0612_AddPartsAssociated_001 {

    @XmlElement(name = "PartsAssociated", namespace = "http://schemas.datastream.net/MP_entities/PartsAssociated_001", required = true)
    protected PartsAssociated partsAssociated;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "confirm_delete_partlocation")
    protected String confirm_Delete_Partlocation;

    /**
     * Gets the value of the partsAssociated property.
     * 
     * @return
     *     possible object is
     *     {@link PartsAssociated }
     *     
     */
    public PartsAssociated getPartsAssociated() {
        return partsAssociated;
    }

    /**
     * Sets the value of the partsAssociated property.
     * 
     * @param value
     *     allowed object is
     *     {@link PartsAssociated }
     *     
     */
    public void setPartsAssociated(PartsAssociated value) {
        this.partsAssociated = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PARTS_ASSOCIATED;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the confirm_Delete_Partlocation property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Delete_Partlocation() {
        if (confirm_Delete_Partlocation == null) {
            return "prompt";
        } else {
            return confirm_Delete_Partlocation;
        }
    }

    /**
     * Sets the value of the confirm_Delete_Partlocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Delete_Partlocation(String value) {
        this.confirm_Delete_Partlocation = value;
    }

}
